@@ -124,7 +124,7 @@ RunnerContext &RunnerContext::operator=(const RunnerContext &other)
     return *this;
 }
 
-/**
+/*!
  * Resets the search term for this object.
  * This removes all current matches in the process and
  * turns off single runner query mode.
@@ -249,7 +249,7 @@ bool RunnerContext::shouldIgnoreCurrentMatchForHistory() const
     return d->shouldIgnoreCurrentMatchForHistory;
 }
 
-/**
+/*!
  * Sets the launch counts for the associated match ids
  *
  * If a runner adds a match to this context, the context will check if the
@@ -265,7 +265,7 @@ void RunnerContext::restore(const KConfigGroup &config)
 
     for (const QString &entry : cfgList) {
         if (int idx = entry.indexOf(QLatin1Char(' ')); idx != -1) {
-            const int count = entry.mid(0, idx).toInt();
+            const int count = QStringView(entry).mid(0, idx).toInt();
             const QString id = entry.mid(idx + 1);
             d->launchCounts[id] = count;
         }
